@@ -1,8 +1,6 @@
 from time import sleep
 from typing import Optional
 
-from plyer import notification
-
 from dvpn.config.constants import PublicVars
 from dvpn.vpns.base import VpnCli
 
@@ -14,12 +12,6 @@ def connect(cli: VpnCli, host: str, bridge: Optional["Bridge"]) -> (bool, dict):
     vpncli = type(cli)(str(creds["cliPath"]))
     try:
         out = vpncli.connect(creds)
-
-        if out[0]:
-            notification.notify(title="DieVpn", message="Successfully Connected")
-        else:
-            notification.notify(title="DieVpn", message="Connection failed")
-
         if bridge:
             bridge.connectStatusChange.emit(host, out[0], False)
             bridge.connectedVPNs.add(host)
